Package: r2rtf
Title: Easily Create Production-Ready Rich Text Format (RTF) Table and
        Figure
Version: 1.1.1
Authors@R: c(
    person("Yilong", "Zhang", role = "aut"),
    person("Siruo", "Wang", role = "aut"),
    person("Simiao", "Ye", role = "aut"),
    person("Fansen", "Kong", role = "aut"),
    person("Brian", "Lang", role = "aut"),
    person("Benjamin", "Wang", , email = "benjamin.wang@merck.com", role = c("aut", "cre")),
    person("Nan", "Xiao", role = "ctb"),
    person("Madhusudhan", "Ginnaram", role = "ctb"),
    person("Ruchitbhai", "Patel", role = "ctb"),
    person("Huei-Ling", "Chen", role = "ctb"),
    person("Peikun", "Wu", role = "ctb"),
    person("Uday Preetham", "Palukuru", role = "ctb"),
    person("Daniel", "Woodie", role = "ctb"),
    person("Sarad", "Nepal", role = "ctb"),
    person("Jane", "Liao", role = "ctb"),
    person("Jeff", "Cheng", role = "ctb"),
    person("Yirong", "Cao", role = "ctb"),
    person("Amin", "Shirazi", role = "ctb"),
    person("Merck Sharp & Dohme Corp", role = "cph")
    )
Description: Create production-ready Rich Text Format (RTF) table and figure
    with flexible format.
License: GPL-3
URL: https://merck.github.io/r2rtf/, https://github.com/Merck/r2rtf
BugReports: https://github.com/Merck/r2rtf/issues
Encoding: UTF-8
VignetteBuilder: knitr
LazyData: true
Depends: R (>= 3.5.0)
Imports: grDevices, tools
Suggests: covr, dplyr, emmeans, ggplot2, knitr, magrittr, officer,
        rmarkdown, stringi, testthat, tidyr, xml2
Config/testthat/edition: 3
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-10-24 22:44:25 UTC; wangben
Author: Yilong Zhang [aut],
  Siruo Wang [aut],
  Simiao Ye [aut],
  Fansen Kong [aut],
  Brian Lang [aut],
  Benjamin Wang [aut, cre],
  Nan Xiao [ctb],
  Madhusudhan Ginnaram [ctb],
  Ruchitbhai Patel [ctb],
  Huei-Ling Chen [ctb],
  Peikun Wu [ctb],
  Uday Preetham Palukuru [ctb],
  Daniel Woodie [ctb],
  Sarad Nepal [ctb],
  Jane Liao [ctb],
  Jeff Cheng [ctb],
  Yirong Cao [ctb],
  Amin Shirazi [ctb],
  Merck Sharp & Dohme Corp [cph]
Maintainer: Benjamin Wang <benjamin.wang@merck.com>
Repository: CRAN
Date/Publication: 2023-10-25 08:00:02 UTC
Built: R 4.4.0; ; 2024-04-29 00:06:32 UTC; unix
